# pywix

Thin wrapper for WiX modelled after pypandoc. Usage:

    pywix.call_wix_command(['candle', ...])
    pywix.call_wix_command(['light', ...])
    pywix.call_wix_command(['heat', ...])
    
In the off chace that anyone else uses this library, pull requests are welcome.
